@@ -5,7 +5,7 @@ GRUNDFOS = ClosedNamespace(
     uri=URIRef("grundfos/", "http://www.knoxproject.aau.dk/"),
     terms=[
         "Manual", "Organisation", "Author", "publishes", "Date", "Publisher", "Page",
-        "Section", "Unit", "Pump", "isWrittenBy", "isPublishedBy", "isPublishedAt", "mentionedOn",
+        "Section", "Unit", "the_pump", "isWrittenBy", "isPublishedBy", "isPublishedAt", "mentionedOn",
         "isInSection", "Title", "Link", "Name", "PublicationDate", "pageNumber",
-        "sectionTitle", "be", "develop"]
+        "sectionTitle"]
 )
